Skip to content

Headers Reference

HTTP headers injected by analysis controllers and available to upstream/downstream services.

ASN

Injected by the maxmind-asn analysis controller.

HeaderExampleDescription
X-ASN-Number15169Autonomous System Number associated with the client IP
X-ASN-OrganizationGOOGLEOrganization name for the ASN

Configuration

yaml
analysisControllers:
  - name: asn-detect
    type: maxmind-asn
    settings:
      databasePath: GeoLite2-ASN.mmdb

GeoIP

Injected by the maxmind-geoip analysis controller.

HeaderExampleDescription
X-GeoIP-CityMountain ViewCity name
X-GeoIP-PostalCode94043Postal/ZIP code
X-GeoIP-RegionCaliforniaState or province name
X-GeoIP-CountryUnited StatesCountry name
X-GeoIP-CountryISOUSISO 3166-1 alpha-2 country code
X-GeoIP-ContinentNorth AmericaContinent name
X-GeoIP-TimeZoneAmerica/Los_AngelesIANA time zone identifier
X-GeoIP-Latitude37.4192Decimal latitude
X-GeoIP-Longitude-122.0574Decimal longitude

Configuration

yaml
analysisControllers:
  - name: geoip-detect
    type: maxmind-geoip
    settings:
      databasePath: GeoLite2-City.mmdb

User Agent

Injected by the ua-detect analysis controller.

Browser Information

HeaderExampleDescription
X-UA-BrowserChromeBrowser name
X-UA-Browser-Version120.0.6099.109Full browser version
X-UA-Browser-Major120Major version number
X-UA-Browser-Minor0Minor version number
X-UA-Browser-Patch6099Patch version number

Operating System

HeaderExampleDescription
X-UA-OS-NamemacOSOperating system name
X-UA-OS-Version10.15.7Full OS version
X-UA-OS-Major10Major version number
X-UA-OS-Minor15Minor version number
X-UA-OS-Platformx86_64Platform architecture

Device Information

HeaderExampleDescription
X-UA-Device-TypedesktopDevice type: desktop, mobile, tablet, bot, tv, unknown
X-UA-Device-MobiletrueBoolean indicating mobile device
X-UA-Device-TabletfalseBoolean indicating tablet device
X-UA-Device-DesktoptrueBoolean indicating desktop device
X-UA-Device-TVfalseBoolean indicating TV device
X-UA-Device-ModeliPhoneDevice model when available

Bot Detection

HeaderExampleDescription
X-UA-Bot-NameGooglebotBot name when detected
X-UA-Bot-URLhttps://www.google.com/bot.htmlBot homepage URL when available

Configuration

yaml
analysisControllers:
  - name: user-agent
    type: ua-detect

Geofence

Injected by the geofence-match match controller.

HeaderExampleDescription
X-Geofence-{controller-name}trueBoolean indicating if the client location matched any feature in the geofence
X-Geofence-{controller-name}-Featureseurope-region,uk-zoneComma-separated list of matched feature names in ascending order (only present when matched)

Configuration

yaml
analysisControllers:
  - name: geoip
    type: maxmind-geoip
    settings:
      databasePath: GeoLite2-City.mmdb

matchControllers:
  - name: europe
    type: geofence-match
    settings:
      featuresFile: config/europe.geojson

NOTE

The geofence-match controller requires the maxmind-geoip analysis controller to provide latitude/longitude data.

Released under the MIT License
Envoy Proxy is a project of the Cloud Native Computing Foundation (CNCF)